==> php-embed_4.4.4.orig.tar.xz: php-embed-4.4.4/tests/fixtures/www.youtube.com.watch.878f5352b6f0e632a763ebf05fb48b16.php <==
<?php
declare(strict_types = 1);

return [
    'authorName' => 'smshdchrb',
    'authorUrl' => 'https://www.youtube.com/user/smshdchrb',
    'cms' => null,
    'code' => [
        'html' => '<iframe width="200" height="150" src="https://www.youtube.com/embed/eiHXASgRTcA?feature=oembed" frameborder="0" allow="accelerometer; autoplay; clipboard-write; encrypted-media; gyroscope; picture-in-picture" allowfullscreen></iframe>',
        'width' => 200,
        'height' => 150,
        'ratio' => 75.0
    ],
    'description' => null,
    'favicon' => 'https://www.google.com/favicon.ico',
    'feeds' => [],
    'icon' => null,
    'image' => 'https://i.ytimg.com/vi/eiHXASgRTcA/hqdefault.jpg',
    'keywords' => [],
    'language' => 'es',
    'languages' => [],
    'license' => null,
    'providerName' => 'YouTube',
    'providerUrl' => 'https://www.youtube.com/',
    'publishedTime' => null,
    'redirect' => 'https://consent.youtube.com/\'https:/consent.youtube.com/ml?continue=https://www.youtube.com/watch?v%3DeiHXASgRTcA&gl=ES&hl=es&pc=yt&uxe=23983172&src=1&rffu=true\'',
    'title' => 'Noisy kittens waiting for dinner!',
    'url' => 'http://www.youtube.com/watch?v=eiHXASgRTcA',
    'linkedData' => [],
    'oEmbed' => [
        'title' => 'Noisy kittens waiting for dinner!',
        'author_name' => 'smshdchrb',
        'author_url' => 'https://www.youtube.com/user/smshdchrb',
        'type' => 'video',
        'height' => 150,
        'width' => 200,
        'version' => '1.0',
        'provider_name' => 'YouTube',
        'provider_url' => 'https://www.youtube.com/',
        'thumbnail_height' => 360,
        'thumbnail_width' => 480,
        'thumbnail_url' => 'https://i.ytimg.com/vi/eiHXASgRTcA/hqdefault.jpg',
        'html' => '<iframe width="200" height="150" src="https://www.youtube.com/embed/eiHXASgRTcA?feature=oembed" frameborder="0" allow="accelerometer; autoplay; clipboard-write; encrypted-media; gyroscope; picture-in-picture" allowfullscreen></iframe>',
        'url' => 'http://www.youtube.com/watch?v=eiHXASgRTcA'
    ]
];

==> php-embed_4.4.7.orig.tar.xz: php-embed-4.4.7/tests/fixtures/www.youtube.com.watch.878f5352b6f0e632a763ebf05fb48b16.php <==
<?php
declare(strict_types = 1);

return [
    'authorName' => 'smshdchrb',
    'authorUrl' => 'https://www.youtube.com/user/smshdchrb',
    'cms' => null,
    'code' => [
        'html' => '<iframe width="200" height="150" src="https://www.youtube.com/embed/eiHXASgRTcA?feature=oembed" frameborder="0" allow="accelerometer; autoplay; clipboard-write; encrypted-media; gyroscope; picture-in-picture" allowfullscreen></iframe>',
        'width' => 200,
        'height' => 150,
        'ratio' => 75.0
    ],
    'description' => null,
    'favicon' => 'https://www.google.com/favicon.ico',
    'feeds' => [],
    'icon' => null,
    'image' => 'https://i.ytimg.com/vi/eiHXASgRTcA/hqdefault.jpg',
    'keywords' => [],
    'language' => 'es',
    'languages' => [],
    'license' => null,
    'providerName' => 'YouTube',
    'providerUrl' => 'https://www.youtube.com/',
    'publishedTime' => null,
    'redirect' => 'https://consent.youtube.com/ml?continue=https://www.youtube.com/watch?v%3DeiHXASgRTcA&gl=ES&hl=es&pc=yt&uxe=23983172&src=1&rffu=true',
    'title' => 'Noisy kittens waiting for dinner!',
    'url' => 'http://www.youtube.com/watch?v=eiHXASgRTcA',
    'linkedData' => [],
    'oEmbed' => [
        'title' => 'Noisy kittens waiting for dinner!',
        'author_name' => 'smshdchrb',
        'author_url' => 'https://www.youtube.com/user/smshdchrb',
        'type' => 'video',
        'height' => 150,
        'width' => 200,
        'version' => '1.0',
        'provider_name' => 'YouTube',
        'provider_url' => 'https://www.youtube.com/',
        'thumbnail_height' => 360,
        'thumbnail_width' => 480,
        'thumbnail_url' => 'https://i.ytimg.com/vi/eiHXASgRTcA/hqdefault.jpg',
        'html' => '<iframe width="200" height="150" src="https://www.youtube.com/embed/eiHXASgRTcA?feature=oembed" frameborder="0" allow="accelerometer; autoplay; clipboard-write; encrypted-media; gyroscope; picture-in-picture" allowfullscreen></iframe>',
        'url' => 'http://www.youtube.com/watch?v=eiHXASgRTcA'
    ]
];
